@@ -47,10 +47,17 @@ async def handle_req(
             writer.write(line)
         await writer.drain()
         writer.close()
-        LOG.info("All lines sent...closing...")
+        LOG.debug("All lines sent...closing...")
     except (ConnectionResetError, BrokenPipeError, CancelledError):
         LOG.info("Cancel received..shutting down...")
         writer.close()
+
+    except Exception as err:
+        LOG.info(f"Unexepcted error! {err}")
+        try:
+            writer.close()
+        except:
+            pass
     LOG.info("Exiting...")
 
 
